#!/usr/bin/env python2

import os
import unittest

from test_helpers import (FieldDetails, ISFDBSubmissionsTestCase, ISFDB_2019_10_19_Mixin,
                          ModeratorActionsFailAsNonModeratorMixin,
                          parse_change_table, verify_button_link,
                          load_xml_file)


class TestAvUpdate(ISFDB_2019_10_19_Mixin, ModeratorActionsFailAsNonModeratorMixin,
                   ISFDBSubmissionsTestCase):
        script = os.path.join(os.path.dirname(__file__), '..', 'av_update.py')
        xml_filename = 'authorupdate.xml'
        sub_type = 2

        def test_av_update_as_moderator(self):
                soup = self.run_script_as_user([self.script, str(self.sub_id)],
                                               run_as='moderator')
                self.assertEqual('Proposed Author Update Submission',
                                 soup.title.text)
                # raw_table = soup.select_one('table.generic_table') # bs4
                raw_table = soup.find('table', {'class': 'generic_table'})
                changed, unchanged = parse_change_table(raw_table)
                self.assertEqual([ u'Birth Date', u'Birth Place',
                                   u'Canonical Name',
                                   u'Death Date', u'Directory Entry',
                                   u'Email Address',
                                   u'Image',
                                   u'Language', u'Legal Name',
                                   u'Trans. Legal Name', u'Transliterated Name'],
                                 sorted(unchanged.keys()))
                self.assertEqual({u'Note':
                                  FieldDetails(current=u'-',
                                               proposed=u'This is a test.',
                                               warning=u''),
                                  u'Web Page':
                                  FieldDetails(current=u'http://www.sf-encyclopedia.com/entry/dalton_test',
                                               # The space between URLs isn't in the value returned by bs4
                                               proposed=u'http://not.a.real.website.test'
                                               u' '
                                               u'http://www.sf-encyclopedia.com/entry/dalton_test',
                                               warning=u''),
                                  },
                                 changed)

                self.verify_hold_and_approval_buttons(soup,
                                                      '/cgi-bin/mod/aa_update.cgi')


if __name__ == '__main__':
        unittest.main()


