#!/usr/bin/env python2

import os

from test_helpers import (FieldDetails, ISFDBSubmissionsTestCase,
                          ISFDB_2019_10_19_Mixin,
                          ModeratorActionsFailAsNonModeratorMixin,
                          parse_proposed_table, verify_button_link,
                          load_xml_file)


class TestPvNew(ISFDB_2019_10_19_Mixin, ModeratorActionsFailAsNonModeratorMixin,
                ISFDBSubmissionsTestCase):
        script = os.path.join(os.path.dirname(__file__), '..', 'pv_new.py')
        xml_filename = 'newpub.xml'
        sub_type = 7

        def test_pv_new_as_moderator(self):
                soup = self.run_script_as_user([self.script, str(self.sub_id)],
                                               run_as='moderator')
                self.assertEqual('Proposed New/Add Publication Submission',
                                 soup.title.text)

                # There are two main tables in this page - a "Title Data" one
                # and a "Publication Data" one.  Currently there's no ID or
                # class to distinguish between them, so we have
                # title_table, publication_table = soup.select('table[border="1"]') # bs4
                title_table, publication_table = soup.findAll('table', {'border': '1'})

                t_proposed, t_warnings = parse_proposed_table(title_table)
                self.assertEqual({
                        u'Authors': u'Test Dalton',
                        u'Content': u'-',
                        u'Graphic Format': u'No',
                        u'Juvenile': u'No',
                        u'Language': u'English',
                        u'Non-Genre': u'No', u'Novelization': u'No',
                        u'Series': u'-', u'Series Number': u'-',
                        u'Synopsis': u'This is a test.',
                        u'Title': u'This is a Test', u'Title Note': u'-',
                        u'Web Page': u'http://this.is.not.a.real.url'
                        }, t_proposed)
                self.assertEqual({}, t_warnings)

                p_proposed, p_warnings = parse_proposed_table(publication_table)
                self.assertEqual({
                        u'Date': u'2019-10-30',
                        u'Pub Type': u'NOVEL',
                        u'Catalog ID': u'-',
                        u'External IDs': u'-',
                        u'Format': 'hc',
                        u'ISBN': u'-', u'Image': u'-',
                        u'Note': u'This is a test.',
                        u'Pages': u'256', u'Price': u'-',
                        u'Publisher': u'Tor',
                        u'Pub Series': u'-', 'Pub Series #': u'-'
                        }, p_proposed)
                self.assertEqual({}, p_warnings)

                self.verify_hold_and_approval_buttons(soup,
                                                      '/cgi-bin/mod/pa_new.cgi')
