#!/usr/bin/env python2

import os

from test_helpers import (FieldDetails, TableCell,
                          ISFDBSubmissionsTestCase, ISFDB_2019_10_19_Mixin,
                          ModeratorActionsFailAsNonModeratorMixin,
                          parse_merge_table, verify_button_link,
                          load_xml_file, parse_table)



class TestTvMerge(ISFDB_2019_10_19_Mixin, ModeratorActionsFailAsNonModeratorMixin,
                  ISFDBSubmissionsTestCase):
        script = os.path.join(os.path.dirname(__file__), '..', 'tv_merge.py')
        xml_filename = 'titlemerge.xml'
        sub_type = 9

        def test_tv_merge_as_moderator(self):
                soup = self.run_script_as_user([self.script, str(self.sub_id)],
                                               run_as='moderator')
                self.assertEqual('Proposed Title Merge Submission',
                                 soup.title.text)
                # raw_table = soup.select_one('table.generic_table') # bs4
                raw_table = soup.find('table', {'class': 'generic_table'})
                keep_id, keep_details, drop_id, drop_details = parse_merge_table(raw_table)

                self.assertEqual(1155736, keep_id)
                self.maxDiff = None
                self.assertEqual({
                        u'Author': TableCell('Matthew Stover', ['drop']),
                        u'ContentIndicator': TableCell('-', ['keep']),
                        u'Graphic': TableCell('No', ['keep']),
                        u'Juvenile': TableCell('No', ['keep']),
                        u'Language': TableCell('English', ['keep']),
                        u'NonGenre': TableCell('No', ['keep']),
                        u'Novelization': TableCell('No', ['keep']),
                        u'Note': TableCell('-', ['keep']),
                        u'Parent': TableCell('-', ['keep']),
                        u'Series': TableCell('Planeswalker Novels', ['keep']),
                        u'Seriesnum': TableCell('-', ['drop']),
                        u'Synopsis': TableCell('-', ['keep']),
                        u'TitleType': TableCell('NOVEL', ['keep']),
                        u'Title': TableCell('Test of Metal', ['keep']),
                        u'TranslitTitles': TableCell('-', ['keep']),
                        u'Storylen': TableCell('-', ['keep']),
                        u'Webpages': TableCell('-', ['keep']),
                        u'Year': TableCell('2010-10-05', ['drop']),
                }, keep_details)


                self.assertEqual(2015329,  drop_id)
                self.assertEqual({
                        u'Author': TableCell('Isaac Hooke', ['keep']),
                        u'ContentIndicator': TableCell('-', ['keep']),
                        u'Graphic': TableCell('No', ['keep']),
                        u'Juvenile': TableCell('No', ['keep']),
                        u'Language': TableCell('English', ['keep']),
                        u'NonGenre': TableCell('No', ['keep']),
                        u'Novelization': TableCell('No', ['keep']),
                        u'Note': TableCell('-', ['keep']),
                        u'Parent': TableCell('-', ['keep']),
                        u'Series': TableCell("Captain's Crucible", ['drop']),
                        u'Seriesnum': TableCell('2', ['keep']),
                        u'Synopsis': TableCell('-', ['keep']),
                        u'TitleType': TableCell('NOVEL', ['keep']),
                        u'Title': TableCell('Test of Mettle', ['drop']),
                        u'TranslitTitles': TableCell('-', ['keep']),
                        u'Storylen': TableCell('-', ['keep']),
                        u'Webpages': TableCell('-', ['keep']),
                        u'Year': TableCell('2016-05-21', ['keep']),
                }, drop_details)

                # TODO (nice-to-have): verify the note to moderator.  Currently
                # the markup isn't explicitly tagged enough to pick out the
                # relevant element accurately/cleanly enough IMHO

                self.verify_hold_and_approval_buttons(soup,
                                                      '/cgi-bin/mod/ta_merge.cgi')
