#!/usr/bin/env python2

import os

from test_helpers import (FieldDetails, ISFDBSubmissionsTestCase, ISFDB_2019_10_19_Mixin,
                          ModeratorActionsFailAsNonModeratorMixin,
                          parse_change_table, verify_button_link,
                          load_xml_file, parse_table)


class TestTvUpdate(ISFDB_2019_10_19_Mixin, ModeratorActionsFailAsNonModeratorMixin,
                   ISFDBSubmissionsTestCase):
        script = os.path.join(os.path.dirname(__file__), '..', 'tv_update.py')
        xml_filename = 'titleupdate.xml'
        sub_type = 8

        def test_tv_update_as_moderator(self):
                soup = self.run_script_as_user([self.script, str(self.sub_id)],
                                               run_as='moderator')
                self.assertEqual('Proposed Title Update Submission',
                                 soup.title.text)
                # raw_table = soup.select_one('table.generic_table') # bs4
                raw_table = soup.find('table', {'class': 'generic_table'})
                changed, unchanged = parse_change_table(raw_table)
                self.assertEqual([u'Authors', u'Content',  u'Date',
                                  u'Graphic Format',u'Juvenile', u'Language', u'Length',
                                  u'Non-Genre', u'Novelization',
                                  u'Series', u'Series Number', u'Synopsis',
                                   u'Title', u'TitleType', u'Transliterated Title',
                                  u'Web Page'],
                                 sorted(unchanged.keys()))
                self.assertEqual({u'Note':
                                  FieldDetails(current=u'-',
                                               proposed=u'This is a note.',
                                               warning=u'')},
                                 changed)
                # TODO (nice-to-have): verify the note to moderator.  Currently
                # the markup isn't explicitly tagged enough to pick out the
                # relevant element accurately/cleanly enough IMHO

                # TODO (nice-to-have): verify the "This title appears in N
                # publications" text.  Similar issues to prior comment.

                # This table could do to be more explicitly marked up
                # raw_table = soup.select_one('table[border=1]') # bs4
                raw_table = soup.find('table', {'border': '1'})
                publication_rows = parse_table(raw_table)
                self.assertEqual([{u'Publication': u'Testing (1993-09-00)',
                                   u'Verification Type': u'Primary',
                                   # This is 'Don Erikson\nBluesman' in bs4 - TODO: make consistent
                                   u'Primary Verifiers': u'Don Erikson Bluesman'
                                   }], publication_rows)

                self.verify_hold_and_approval_buttons(soup,
                                                      '/cgi-bin/mod/ta_update.cgi')

